start

# Mac OSX strings

Mac OSX .strings files are used for some Cocoa / Carbon application localization, such as for the iPhone, iPod, and OSX. They are somewhat similar to Java properties, and therefore prop2po and po2prop is used for conversion.

This is supported by the Translate Toolkit since version 1.8.0.

## References

- Localising string resources
- manual creation of .strings files
- String format specifiers